@@ -1,4 +1,4 @@
-# mod_11_2.py - functions for performing the ISO 7064 Mod 11, 2 algorithm
+# mod_37_36.py - functions for performing the ISO 7064 Mod 37, 36 algorithm
 #
 # Copyright (C) 2010 Arthur de Jong
 #
@@ -18,41 +18,45 @@
 # 02110-1301 USA
 
 """Module for calculation and verifying the checksum of a number
-using the ISO 7064 Mod 11, 2 algorithm.
+using the ISO 7064 Mod 37, 36 algorithm.
 
 Validation can be done with is_valid(). A valid number can be made by
 calculating the check digit and appending it.
 
->>> calc_check_digit('0794')
-'0'
->>> is_valid('07940')
-True
->>> calc_check_digit('079')
-'X'
->>> is_valid('079X')
-True
->>> checksum('079X')
+>>> checksum('A12425GABC1234002M')
 1
+>>> calc_check_digit('A12425GABC1234002')
+'M'
+>>> is_valid('A12425GABC1234002M')
+True
+
+By changing the alphabet this can be turned into any Mod x+1, x
+algorithm. For example Mod 11, 10:
+
+>>> calc_check_digit('00200667308', alphabet='0123456789')
+'5'
+>>> is_valid('002006673085', alphabet='0123456789')
+True
 """
 
 
-def checksum(number):
+def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Calculate the checksum."""
-    check = 0
+    modulus = len(alphabet)
+    check = modulus / 2
     for n in number:
-        check = ( 2 * check + int(10 if n == 'X' else n) ) % 11
+        check = ( ((check or modulus) * 2) % (modulus + 1) + alphabet.index(n) ) % modulus
     return check
 
-def calc_check_digit(number):
+def calc_check_digit(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """With the provided number, calculate the extra digit that should be
     appended to make it a valid number."""
-    c = (1 - 2 * checksum(number) ) % 11
-    return 'X' if c == 10 else str(c)
+    modulus = len(alphabet)
+    return alphabet[(1 - ( (checksum(number, alphabet) or modulus) * 2) % (modulus + 1) ) % modulus]
 
-def is_valid(number):
+def is_valid(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     """Checks whether the check digit is valid."""
     try:
-        return bool(number) and checksum(number) == 1
+        return bool(number) and checksum(number, alphabet) == 1
     except:
         return False
-
