@@ -38,16 +38,16 @@ True
 # Verhoeff algorithm.
 
 _multiplication_table = (
-    ( 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 ),
-    ( 1, 2, 3, 4, 0, 6, 7, 8, 9, 5 ),
-    ( 2, 3, 4, 0, 1, 7, 8, 9, 5, 6 ),
-    ( 3, 4, 0, 1, 2, 8, 9, 5, 6, 7 ),
-    ( 4, 0, 1, 2, 3, 9, 5, 6, 7, 8 ),
-    ( 5, 9, 8, 7, 6, 0, 4, 3, 2, 1 ),
-    ( 6, 5, 9, 8, 7, 1, 0, 4, 3, 2 ),
-    ( 7, 6, 5, 9, 8, 2, 1, 0, 4, 3 ),
-    ( 8, 7, 6, 5, 9, 3, 2, 1, 0, 4 ),
-    ( 9, 8, 7, 6, 5, 4, 3, 2, 1, 0 ) )
+    [ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 ],
+    [ 1, 2, 3, 4, 0, 6, 7, 8, 9, 5 ],
+    [ 2, 3, 4, 0, 1, 7, 8, 9, 5, 6 ],
+    [ 3, 4, 0, 1, 2, 8, 9, 5, 6, 7 ],
+    [ 4, 0, 1, 2, 3, 9, 5, 6, 7, 8 ],
+    [ 5, 9, 8, 7, 6, 0, 4, 3, 2, 1 ],
+    [ 6, 5, 9, 8, 7, 1, 0, 4, 3, 2 ],
+    [ 7, 6, 5, 9, 8, 2, 1, 0, 4, 3 ],
+    [ 8, 7, 6, 5, 9, 3, 2, 1, 0, 4 ],
+    [ 9, 8, 7, 6, 5, 4, 3, 2, 1, 0 ] )
 
 _permutation_table = (
     ( 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 ),
